//
// Copyright (C) 1999-2006 WideStudio/MWT Project Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
//

  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","","");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","B4:WSSTR Confirmation","");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","C4:WSSTR ObjectBox","IuWFNg{bNX");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","D4:WSSTR ProjectSettings","vWFNgݒ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","E4:WSSTR New project","vWFNg̐VK쐬");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","F4:WSSTR Open project","vWFNg̓ǂݍ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","G4:WSSTR Save project","vWFNg̕ۑ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","H4:WSSTR Close project","vWFNg̏I");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","I4:WSSTR New application window","EBhE̐VK쐬");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","J4:WSSTR Open application window","EBhE̓ǂݍ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","K4:WSSTR Save application window","EBhE̕ۑ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","L4:WSSTR Delete instance","EBhE/IuWFNg̍폜");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","M4:WSSTR Properties","vpeBҏW");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","N4:WSSTR Procedures","vV[Wݒ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","O4:WSSTR Display the object box","IuWFNg{bNX");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","P4:WSSTR Project settings","vWFNg̐ݒ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","Q4:WSSTR Build all","rhI[");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","Q4:WSSTR Cancel","rh~");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","R4:WSSTR Execute","s");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","S4:WSSTR Find instances","EBhE/CX^X̌");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","T4:WSSTR Find files","t@C");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","U4:WSSTR Help","wv");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","V4:WSSTR  File(F)"," t@C(F)");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","W4:WSSTR New window(N)         :m11:N,Open window(O):m12:O,Save window(S):m13:S,Save as(R):m14:R,Save all(A):m15:A,SP,Exit(X):m16:X","VKEBhE(N)      :m11:N:0:$(WSDIR)/sys/pixmaps/wcreate.png,EBhEǂݍ(O):m12:O:0:$(WSDIR)/sys/pixmaps/wload.png,EBhEۑ(S):m13:S:0:$(WSDIR)/sys/pixmaps/wsave.png,EBhEʖۑ(R):m14:R:0:,EBhESۑ(A):m15:A:0:,SP,r_I(X):m16:X:0:$(WSDIR)/sys/pixmaps/pend.png");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","X4:WSSTR  Edit(E)"," ҏW(E)");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","Y4:WSSTR Copy(C):m21:C,Paste(P):m22:P,SP,Display(I):m27:I,Find(F):m28:F,Delete(D):m23:D,SP,Properties(R):m24:R,Procedures:{List up(L):m25:L,New procedure(N):m251:N,Properties(S):m252:S,Edit(E):m253:E,Delete(X):m254:X},Attributes(A):m26:A,Files(L):m29:L","ɖ߂(U):m291:U:1,(C):m21:C,\x93\\t(P):m22:P,SP,\x95\\(I):m27:I,CX^X̌(F):m28:F,폜(D):m23:D,SP,vpeBҏW(R):m24:R,vV[WҏW:{vV[Wꗗ(L):m25:L,vV[WVK쐬(N):m251:N,vV[Wݒ(S):m252:S,vV[WҏW(E):m253:E,vV[W폜(X):m254:X},{ݒ(A):m26:A,t@Cꗗ(L):m29:L");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","Z4:WSSTR  Build(B)"," rh(B)");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","a4:WSSTR Compile(C)    :m31:C,Build all(B):m32:B,Rebuild(R):m33:R,Clean(E):m34:E,SP,Debug(D):m35:D,Execute(X):m36:X,Execute with Trace(T):m39:T,SP,Generate source(G):m37:G,Generate inf file(I):m38:I","RpC(C)    :m31:C,rhI[(B):m32:B:0:$(WSDIR)/sys/pixmaps/make.png,rh(R):m33:R,N[(E):m34:E,SP,fobO(D):m35:D,s(X):m36:X:0:$(WSDIR)/sys/pixmaps/run.png,g[Xs(T):m39:T,SP,\x83\\[X̐(G):m37:G,\x8d\\̏o(I):m38:I");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","b4:WSSTR Compile(C)    :m31:C,Build all(B):m32:B,Rebuild(R):m33:R,Clean(E):m34:E,SP,Debug(D):m35:D,Abort(X):m36:X,SP,Generate source(G):m37:G,Generate inf file(I):m38:I","RpC(C)    :m31:C,rhI[(B):m32:B:0:$(WSDIR)/sys/pixmaps/make.png,rh(R):m33:R,N[(E):m34:E,SP,fobO(D):m35:D,s~(X):m36:X:0:$(WSDIR)/sys/pixmaps/runx.png,SP,\x83\\[X̐(G):m37:G,\x8d\\̏o(I):m38:I");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","c4:WSSTR  View(V)"," \x95\\(V)");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","d4:WSSTR ObjectBox(O) :m41:O,Component(C)    :m42:C,ToolBar(B):m43:B,Terminal(T):m45:T","tH_(D) :m46:D,CXyN^(I) :m47:I,CX^XGfB^(E) :m48:E,NXXg(L) :m49:L,IuWFNg{bNX(O)     :m41:O:0:$(WSDIR)/sys/pixmaps/obox.png,R|[lg(C):m42:C,c[o[(B):m43:B,SP,^[~i(T):m45:T");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","e4:WSSTR ObjectBox(O) :m41:O,Component(C)    :m42:C,ToolBar(B):m43:B,Find Files(F):m44:F,Terminal(T):m45:T","tH_(D) :m46:D,CXyN^(I) :m47:I,CX^XGfB^(E) :m48:E,NXXg(L) :m49:L,IuWFNg{bNX(O)     :m41:O:0:$(WSDIR)/sys/pixmaps/obox.png,R|[lg(C):m42:C,c[o[(B):m43:B,SP,t@C(F):m44:F,^[~i(T):m45:T");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","f4:WSSTR  Project(P)"," vWFNg(P)");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","g4:WSSTR New project(N)        :m51:N,Open project(O):m52:O,Save project(S):m53:S,Rename project(R):m54:R,SP,Project settings(E):m55:E,SP,Close project(C):m56:C","VKvWFNg(N)      :m51:N:0:$(WSDIR)/sys/pixmaps/pcreate.png,vWFNgǂݍ(O) :m52:O:0:$(WSDIR)/sys/pixmaps/pload.png,vWFNgۑ(S):m53:S:0:$(WSDIR)/sys/pixmaps/psave.png,vWFNgʖۑ(R):m54:R,SP,vWFNgݒ(E):m55:E:0:$(WSDIR)/sys/pixmaps/pset.png,SP,vWFNgI(C):m56:C:0:$(WSDIR)/sys/pixmaps/pend.png");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","h4:WSSTR  Option(O)"," IvV(O)");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","i4:WSSTR Environment(E)    :m61:E,SP,Colors(C):m62:C,Fonts(F):m63:F,Look and Feel(L):m64:L","ݒ(E)      :m61:E:0:$(WSDIR)/sys/pixmaps/pset.png,SP,Fݒ(C):m62:C,tHgݒ(F):m63:F,bNAhtB[(L):m64:L");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","j4:WSSTR  Help(H)"," wv(H)");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","k4:WSSTR Index(I):m81:I,Reference(R)     :m82:R,User's guide(U):m83:U,About WideStudio(V):m84:V,License(L):m85:L","ڎ(I):m81:I:0:$(WSDIR)/sys/pixmaps/help.png,t@X(R)     :m82:R,g(U):m83:U,o[W(V):m84:V,CZX(L):m85:L");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","l4:WSSTR Please specify a window to save.","ۑEBhEIĉ.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","m4:WSSTR Continue saving?","ۑ𑱂܂.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","n4:WSSTR Please specify some instances to copy.","Rs[CX^XIĂ.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","o4:WSSTR Please specify a instance to paste.","\x93\\tIĂ.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","p4:WSSTR Some instances are selected to paste.\nPlease specify a instance.","\x93\\t悪IĂ܂.\nIĉ.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","q4:WSSTR Please select the instance to delete.","폜CX^XIĂ.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","r4:WSSTR Delete instance: ","CX^X: ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","s4:WSSTR  ?"," 폜܂H");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","t4:WSSTR Please specify a instance to display.","\x95\\CX^XIĂ. ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","u4:WSSTR There is no instance for search.","ΏۂƂȂIuWFNg^CX^X܂B");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","v4:WSSTR Please specify a application window to compile.","RpCEBhEIĉ.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","w4:WSSTR Please check the debugger settings or confirm whether the project is built.","fobK̎w肪ACNĂ邩mFĉB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","x4:WSSTR Can not execute the class library...","Cu̎s͏o܂B");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","y4:WSSTR Can not execute the load module.\nPlease confirm whether the project is collect or built.","[hW[sł܂B\nvWFNgACNĂ邩mFĉB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","z4:WSSTR Please specify a application window to generate source code.","\x83\\[X𐶐EBhEIĉ.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","A4:WSSTR Please wait for a while to start web browser..","wvuEUオ܂B΂炭҂...");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","B4:WSSTR NoName","");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","C4:WSSTR Unexpected error occurred in reading the project files...","vWFNg̓ǂݍ݂ŃG[܂B");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","D4:WSSTR Can not open File: ","o^t@C: ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","E4:WSSTR  .","\n̓ǂݍ݂ŃG[܂B");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","F4:WSSTR Can not save FILE: ","FILE: ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","G4:WSSTR  .","̏o͂Ɏs܂B");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","H4:WSSTR The project was modified.\nSave it?","vWFNgύXĂ܂B\nۑ܂H");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","I4:WSSTR Abort saving the application window.","EBhE̕ۑ𒆒f܂B");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","J4:WSSTR Some application windows were modified \nSave them?","EBhEύXĂ܂B\nۑ܂H");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","K4:WSSTR The project has no name.\nName the project and save it?","vWFNgłB\n̂tĕۑ܂?");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","L4:WSSTR Exit the application builder?","r_I܂H");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","M4:WSSTR Sorry, under construction...","݂܂񂪁AHłEEE");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","N4:WSSTR Failed to save FILE: ","FILE: ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","O4:WSSTR Do you continue?","̏o͂Ɏs܂Bo͂𑱂܂H");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","P4:WSSTR \",\n","쐬܂\",\n");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","Q4:WSSTR No project is specified.\nGenerate a new project?","vWFNgw肳Ă܂B\nvWFNgJAVvWFNg𐶐Ă.\nvWFNg𐶐܂?");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","R4:WSSTR Please specify a keyword to search files.","t@CɊ܂܂镶w肵Ă.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","S4:WSSTR No editor is specified.\nPlease confirm the project settings and specify the editor.","GfB^w肳Ă܂B\nvWFNgݒŃGfB^w肵ĂB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","S4:WSSTR No editor option is specified.\nPlease confirm the project settings and specify the editor.","GfB^IvVw肳Ă܂B\nvWFNgݒŃGfB^IvVw肵ĂB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","T4:WSSTR New project","vWFNg̍쐬");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","U4:WSSTR < Back,Next >,Finish","< ߂, >,");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","V4:WSSTR Project name","vWFNg");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","W4:WSSTR Working dir","ƃfBNg");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","X4:WSSTR Project type","vWFNg");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","Y4:WSSTR  Normal application"," ʏ̃AvP[V");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","Z4:WSSTR  Class library component"," NXCuR|[lg");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","W4:WSSTR New application window","EBhE̍쐬");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","X4:WSSTR < Back,Next >,Finish","< ߂, >,");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","Y4:WSSTR Type","^Cv");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","Z4:WSSTR  Normal window"," ʏ̃EBhE");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","a4:WSSTR  Class"," NX");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","b4:WSSTR Project","o^");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","c4:WSSTR  Add to project"," vWFNgɓo^");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","d4:WSSTR Name","");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","e4:WSSTR Please specify a instance name to search.","(CX^X)w肵ĉB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","f4:WSSTR Please specify a value of the property to search instance.","(vpeBl)w肵ĉB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","f4:WSSTR Please specify a property name likes [WSN...] to search instance.","WSN... Ŏn܂vpeBw肵ĉB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","g4:WSSTR Please specify search condition.","w肵ĉB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","h4:WSSTR No instance.","w肳ꂽCX^X͌t܂ł.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","i4:WSSTR Find instances","CX^X̌");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","j4:WSSTR Find","");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","k4:WSSTR Instance name,Properties,Procedures","CX^X,vpeB,vV[W");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","l4:WSSTR InstanceName","CX^X");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","m4:WSSTR Comparison","@");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","n4:WSSTR  Complete equal","Sv");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","o4:WSSTR PropertyName","vpeB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","p4:WSSTR Value","vpeBl");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","q4:WSSTR ProcedureName","vV[W");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","r4:WSSTR FunctionName","֐");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","s4:WSSTR Direction","");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","t4:WSSTR  Downward"," ֌");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","u4:WSSTR  Upward"," ֌");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","v4:WSSTR Find files","t@Č");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","w4:WSSTR < Back,Find, Find","< ߂,, ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","x4:WSSTR Dir:","ꏊ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","y4:WSSTR File type:","t@C^Cv");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","z4:WSSTR Keyword:","܂ޕ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","A4:WSSTR Failed to save FILE: ","FILE: ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","B4:WSSTR .","\n̏o͂Ɏs܂B");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","C4:WSSTR Delete instance:","CX^X:");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","D4:WSSTR ?","\n폜Ă낵łH");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","E4:WSSTR Add application window: ","EBhE: ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","F4:WSSTR  to the project?"," vWFNg֓o^܂H");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","G4:WSSTR Remove application window: ","EBhE: ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","H4:WSSTR  from the project?"," vWFNgւ̓o^܂H");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","I4:WSSTR Failed to read file:","t@C: ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","J4:WSSTR .\nDo you stop reading?","\n̓ǂݍݒɃG[܂B\nǂݍ݂𒆎~܂H");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","K4:WSSTR Failed to open File: ","t@C: ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","L4:WSSTR .","\nI[vł܂łB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","M4:WSSTR Failed to write File: ","t@C: ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","N4:WSSTR .","\nŏ݃G[܂B");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","O4:WSSTR Invalid name: ","Ȗ: ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","P4:WSSTR .\nPlease specify a usable name in C/C++ variables.","\n C/C++Ŏgpłϐ̂w肵ĂB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","P4:WSSTR .\nAlready used by project name.",".\nvWFNgƈقȂ閼̂w肵ĉB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","P4:WSSTR .\nCan not use array name.",".\nz񖼂͎wł܂B");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","Q4:WSSTR Can not generate the specified class: ","w肳ꂽNX: ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","R4:WSSTR ."," 𐶐o܂B");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","S4:WSSTR Can not change the specified class: ","w肳ꂽNX: ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","T4:WSSTR  to window type.\nPlease specify a class of window/dialog base."," ̓EBhEɏo܂B\n EBhEx[XƂNXw肵ĉB");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","U4:WSSTR Can not paste the instance on the specified instance: ","CX^X: ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","V4:WSSTR ."," ɑ΂\ñCX^X\x93\\t邱Ƃ͂ł܂.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","W4:WSSTR Can not paste the specified instance: ","CX^X: ");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","X4:WSSTR ,\nbecause it overlap the source and the destination...","Rs[ƃRs[dȂĂ܂.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","Y4:WSSTR Locale type","P[");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","Y4:WSSTR Language","");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","Y4:WSSTR Templates","ev[g");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","Z4:WSSTR Can not read file:","t@C:");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","a4:WSSTR .","\n ǂݍ߂܂łB$(WSDIR) ̐ݒmFĉ.");
  WSGIappLocaleSet()->setLocaleString("ja_JP.sjis","a4:WSSTR Look and Feel","bNAhtB[");
